from exceptions import common as common_exc, http as http_exc


class BaseController:
    repo = None

    async def get_list(self, **kwargs) -> list[dict]:
        return await self.repo.get_list(**kwargs)

    async def get(self, id: int) -> dict:
        try:
            return await self.repo.get(id)

        except common_exc.NotFoundException as e:

            raise http_exc.HTTPNotFoundException(detail=str(e))

    async def create(self, **data) -> dict:
        try:
            return await self.repo.create(**data)

        except common_exc.CreateException as e:

            raise http_exc.HTTPBadRequestException(detail=str(e))

    async def update(self, id: int, **kwargs) -> dict:
        try:
            return await self.repo.update(id, **kwargs)

        except common_exc.NotFoundException as e:

            raise http_exc.HTTPNotFoundException(detail=str(e))

        except common_exc.UpdateException as e:

            raise http_exc.HTTPBadRequestException(detail=str(e))

    async def delete(self, id: int) -> None:
        try:
            return await self.repo.delete(id)

        except common_exc.NotFoundException as e:

            raise http_exc.HTTPNotFoundException(detail=str(e))

        except common_exc.DeleteException as e:

            raise http_exc.HTTPBadRequestException(detail=str(e))
