from enum import Enum

from tortoise import fields, models

from .base import BaseModel


class Product(BaseModel):
    name = fields.CharField(max_length=255)
    description = fields.TextField(null=True, default=None)
    price = fields.FloatField()
    image = fields.TextField()

    def __str__(self):
        return self.name

    class Meta(BaseModel.Meta):
        table = 'products'


class Order(BaseModel):
    class StatusEnum(str, Enum):
        IN_PROCESSING = 'IN_PROCESSING'
        CONFIRMED = 'CONFIRMED'
        COMPLETED = 'COMPLETED'

    products = fields.ManyToManyField(
        'models.Product', related_name='order_products',
        through='products_orders'
    )
    status = fields.CharEnumField(enum_type=StatusEnum, default=StatusEnum.IN_PROCESSING)
    total = fields.DecimalField(max_digits=10, decimal_places=2, default=0.0)

    def __str__(self):
        return f'Order #{self.id}'

    class Meta(BaseModel.Meta):
        table = 'orders'


class ProductOrder(models.Model):
    order = fields.ForeignKeyField('models.Order', related_name='order_products')
    product = fields.ForeignKeyField('models.Product', related_name='product_orders')
    quantity = fields.IntField(default=1)

    class Meta(BaseModel.Meta):
        table = 'products_orders'
